@@ -63,7 +63,7 @@ CSSFontFaceSource::~CSSFontFaceSource()
             WTF::Vector<DOMString> names = m_face->familyNames();
             unsigned size = names.size();
             for (unsigned i = 0; i < size; i++) {
-                QFont::removeSubstitution(names[i].string());
+                QFont::removeSubstitutions(names[i].string());
                 khtml::Font::invalidateCachedFontFamily(names[i].string());
             }
             QFontDatabase::removeApplicationFont(m_id);
@@ -765,7 +765,7 @@ static inline bool compareFontFaces(CSSFontFace *first, CSSFontFace *second)
         return true;
     }
 
-    // http://www.w3.org/TR/2002/WD-css3-webfonts-20020802/#q46 says: "If there are fewer then 9 weights in the family, the default algorithm
+    // https://www.w3.org/TR/2002/WD-css3-webfonts-20020802/#q46 says: "If there are fewer then 9 weights in the family, the default algorithm
     // for filling the "holes" is as follows. If '500' is unassigned, it will be assigned the same font as '400'. If any of the values '600',
     // '700', '800', or '900' remains unassigned, they are assigned to the same face as the next darker assigned keyword, if any, or the next
     // lighter one otherwise. If any of '300', '200', or '100' remains unassigned, it is assigned to the next lighter assigned keyword, if any,
